==> flutter_conscent_plugin-0.3.8.tar.gz: lib/web_view_default.dart <==
import 'dart:io' show Platform;

import 'package:flutter/material.dart';
import 'package:http/http.dart' as http;
import 'package:shared_preferences/shared_preferences.dart';
import 'package:webview_flutter/webview_flutter.dart';

import 'conscent_initializer.dart';
import 'conscent_methods.dart';
import 'constants.dart';
import 'datamodel/api_mode.dart';
import 'datamodel/login_challengeget.dart';

void main() {
  runApp(
    const MaterialApp(
      home: WebViewDefaultApp(
        redirectUrl: '',
      ),
    ),
  );
}

class WebViewDefaultApp extends StatefulWidget {
  final String redirectUrl;
  const WebViewDefaultApp({Key? key, required this.redirectUrl})
      : super(key: key);

  @override
  State<WebViewDefaultApp> createState() => _WebViewDefaultAppState();
}

class _WebViewDefaultAppState extends State<WebViewDefaultApp> {
  String? loginId;
  // String? sessionId;

  bool showContent = false;
  bool isLoaded = false;

  @override
  void initState() {
    if (mounted) {
      getLoginChallengeId();
    }
    super.initState();
  }

  @override
  void dispose() {
    super.dispose();
    ConscentMethods().pageViewEvent(0, 0);
  }

  getLoginChallengeId() async {
    final prefs = await SharedPreferences.getInstance();
    loginId = prefs.getString('loginID');
    print("WebViewDefaultApp loginId.toString()  ${loginId.toString()}");
    getSessionID(loginId.toString());
    setState(() {});
  }

  Future<String> getSessionID(String loginId) async {
    var uri = Uri.parse('${APIMode.BASE_URL}api/v1/login-challenge/$loginId');
    var response = await http.get(uri);
    if (response.statusCode == 200) {
      LoginChallengeget loginChallengeget =
          loginChallengegetFromJson(response.body);
      final prefs = await SharedPreferences.getInstance();
      String sessionId = loginChallengeget.toString();
      prefs.setString('sessionId', sessionId);
      const CircularProgressIndicator();
      return sessionId;
    } else {
      ConscentMethods().onPluginError(response.body);
    }
    return '';
  }

  Future<void> submitDatas(
      String clientId, String clientContentId, String sessionId) async {
    var response = await http
        .post(Uri.parse('${APIMode.BASE_URL}api/v1/content/access'), body: {
      "clientId": '${ConscentInitializer.mClientId}',
      "clientContentId": '${ConscentInitializer.mContentId}',
      "sessionId": sessionId,
    });

    if (response.statusCode == 201) {
      var responseString = response.body;

      Navigator.pop(context, {"response": responseString});
    } else {
      ConscentMethods().onPluginError(response.body);
    }
  }

  JavascriptChannel _javascriptChannel() {
    print('javascript');
    return JavascriptChannel(
        name: 'LOGINCHALLENGE',
        onMessageReceived: (JavascriptMessage message) async {
          print("WebViewDefaultApp message.message ${message.message}");
          if (message.message == 'loginSuccess') {
            const CircularProgressIndicator();
            String sessionId = await getSessionID(loginId!);
            submitDatas('${ConscentInitializer.mClientId}',
                '${ConscentInitializer.mContentId}', sessionId);
          }
        });
  }

  // Home

  Widget homeBody() {
    return !isLoaded
        ? const CircularProgressIndicator()
        : const Padding(
            padding: EdgeInsets.all(8.0),
          );
  }

  //home

  // ... to here.

  @override
  Widget build(BuildContext context) {

    <JavascriptChannel>{_javascriptChannel()};

    String? userAgent = Constants.userAgent;
    print("widget.userAgent ${userAgent?.replaceAll("; wv", "")}");
    print("initialUrl ${widget.redirectUrl}");
    //"Mozilla/5.0 (Linux; Android 12; RMX2121 Build/SP1A.210812.016; wv) AppleWebKit/537.36 (KHTML, like Gecko) Version/4.0 Chrome/109.0.5414.86 Mobile Safari/537.36",
    //Mozilla/5.0 (Linux; Android 13; sdk_gphone64_arm64 Build/TE1A.220922.012) AppleWebKit/537.36 (KHTML, like Gecko) Version/4.0 Chrome/103.0.5060.71 Mobile Safari/537.36

    //widget.redirectUrl Mozilla/5.0 (iPhone; CPU iPhone OS 16_2 like Mac OS X) AppleWebKit/605.1.15 (KHTML, like Gecko) Mobile/15E148
    // "userAgent":       "Mozilla/5.0 (iPhone; CPU iPhone OS 16_2 like Mac OS X) AppleWebKit/605.1.15 (KHTML, like Gecko)"
    return Scaffold(
      appBar: AppBar(
        title: const Text('Conscent'),
      ),
      body: loginId != null
          ? WebView(
              initialUrl: widget.redirectUrl,
              javascriptMode: JavascriptMode.unrestricted,
              userAgent: Platform.isIOS
                  ? '${userAgent!} Safari/605.1'
                  : userAgent?.replaceAll("; wv", ""),
              onProgress: (int progress) async {
                <JavascriptChannel>{_javascriptChannel()};
              },
              onWebViewCreated: (controller) {

              },
              navigationDelegate: (NavigationRequest request) {


                if (request.url.startsWith('https://xyz.zyz')) {


                  getSessionID(loginId!);

                  return NavigationDecision.prevent;
                }

                return NavigationDecision.navigate;
              },
              onPageStarted: (String url) {

              },
              onPageFinished: (String url) {

              },
              javascriptChannels: <JavascriptChannel>{_javascriptChannel()},
            )
          : const Center(child: CircularProgressIndicator()),
    );
  }
}

==> flutter_conscent_plugin-0.4.0.tar.gz: lib/web_view_default.dart <==
import 'dart:io' show Platform;

import 'package:flutter/material.dart';
import 'package:http/http.dart' as http;
import 'package:shared_preferences/shared_preferences.dart';
import 'package:webview_flutter/webview_flutter.dart';

import 'conscent_initializer.dart';
import 'conscent_methods.dart';
import 'constants.dart';
import 'datamodel/api_mode.dart';
import 'datamodel/login_challengeget.dart';

class WebViewDefaultApp extends StatefulWidget {
  final String redirectUrl;
  const WebViewDefaultApp({Key? key, required this.redirectUrl,required this.controller})
      : super(key: key);
  final WebViewController controller;
  @override
  State<WebViewDefaultApp> createState() => _WebViewDefaultAppState();
}

class _WebViewDefaultAppState extends State<WebViewDefaultApp> {
  String? loginId;
  // String? sessionId;
  var loadingPercentage = 0;
  bool showContent = false;
  bool isLoaded = false;

  @override
  void initState() {
    if (mounted) {
      getLoginChallengeId();
    }
    super.initState();

    widget.controller
      ..setNavigationDelegate(
        NavigationDelegate(
          onPageStarted: (url) {
            print(url);
            // setState(() {
            //   loadingPercentage = 0;
            // });
          },
          onProgress: (progress) {

            // setState(() {
            //   loadingPercentage = progress;
            // });
          },
          onPageFinished: (url) {
            print(url);
            // setState(() {
            //   loadingPercentage = 100;
            // });
          },
          onNavigationRequest: (navigation) {
            final host = Uri.parse(navigation.url).host;
            if (host.contains('https://xyz.zyz')) {

              getSessionID(loginId!);

              return NavigationDecision.prevent;
            }
            return NavigationDecision.navigate;
          },
        ),
      )
      ..setJavaScriptMode(JavaScriptMode.unrestricted)..addJavaScriptChannel(
      'LOGINCHALLENGE',
      onMessageReceived: (message) async {
        print(message.message);
        if (message.message == 'loginSuccess') {
          CircularProgressIndicator();
          print('javascript----------');
          String sessionId = await getSessionID(loginId!);
          submitDatas('${ConscentInitializer.mClientId}',
              '${ConscentInitializer.mContentId}', sessionId);
        }
      },
    );
  }

  @override
  void dispose() {
    super.dispose();
    ConscentMethods().pageViewEvent(0, 0);
  }

  getLoginChallengeId() async {
    final prefs = await SharedPreferences.getInstance();
    loginId = prefs.getString('loginID');
    print("WebViewDefaultApp loginId.toString()  ${loginId.toString()}");
    getSessionID(loginId.toString());
    setState(() {});
  }

  Future<String> getSessionID(String loginId) async {
    var uri = Uri.parse('${APIMode.BASE_URL}api/v1/login-challenge/$loginId');
    var response = await http.get(uri);
    if (response.statusCode == 200) {
      LoginChallengeget loginChallengeget =
          loginChallengegetFromJson(response.body);
      final prefs = await SharedPreferences.getInstance();
      String sessionId = loginChallengeget.toString();
      prefs.setString('sessionId', sessionId);
      const CircularProgressIndicator();
      return sessionId;
    } else {
      ConscentMethods().onPluginError(response.body);
    }
    return '';
  }

  Future<void> submitDatas(
      String clientId, String clientContentId, String sessionId) async {
    var response = await http
        .post(Uri.parse('${APIMode.BASE_URL}api/v1/content/access'), body: {
      "clientId": '${ConscentInitializer.mClientId}',
      "clientContentId": '${ConscentInitializer.mContentId}',
      "sessionId": sessionId,
    });

    if (response.statusCode == 201) {
      var responseString = response.body;

      Navigator.pop(context, {"response": responseString});
    } else {
      ConscentMethods().onPluginError(response.body);
    }
  }



  // Home

  Widget homeBody() {
    return !isLoaded
        ? const CircularProgressIndicator()
        : const Padding(
            padding: EdgeInsets.all(8.0),
          );
  }


  @override
  Widget build(BuildContext context) {
    return Stack(
      children: [
        WebViewWidget(
          controller: widget.controller..loadRequest(Uri.parse(widget.redirectUrl)),
        )
      ],
    );
  }
}
